## Linuxmedia is a wrapper for 60 above 60+ Linux Commands

#### Prerequisites


On Ubuntu/Debian:

```
sudo apt install update
sudo apt install upgrade
```



#### Usage

To get all available info about Linuxmedia Command and Its usage :
```
linuxmedia <command> [Options..]

```
